==> glx.ui-1.8.20.tgz: package/components/slider/slider.ts <==
import {
    NgModule,
    Component,
    Input,
    Output,
    OnInit, OnChanges, SimpleChanges, HostListener,
    EventEmitter
} from '@angular/core';
import { CommonModule } from '@angular/common';
import { slideInOutAnimation } from '../kernel/animations/slide.animation';

/**
 * Слайдер
 */
@Component({
    selector: 'glx-slider',
    styleUrls: ['slider.scss'],
    templateUrl: 'slider.html',
    animations: [slideInOutAnimation]
})
export class Slider implements OnInit, OnChanges {
    /**
     * Признак открытого / закрытого слайдера
     */
    @Input() open: boolean;
    /**
     * Заголовок слайдера
     */
    @Input() header: string;
    /**
     * Показать кнопку отмены
     * @type {boolean}
     */
    @Input() showCancelBtn: boolean = false;
    /**
     * Показать кнопку сохранить
     * @type {boolean}
     */
    @Input() showSaveBtn: boolean = false;

    /**
     * Событие на смену видимости слайдера
     * @type {EventEmitter<boolean>}
     */
    @Output() openChange = new EventEmitter<boolean>();
    /**
     * Событие на открытие слайдера
     * @type {EventEmitter<any>}
     */
    @Output() onOpen: EventEmitter<any> = new EventEmitter();
    /**
     * Собатие на закрытие слайдера
     * @type {EventEmitter<any>}
     */
    @Output() onClose: EventEmitter<any> = new EventEmitter();
    /**
     * Собыытие на нажатие кнопки отмены
     * @type {EventEmitter<any>}
     */
    @Output() onCancel: EventEmitter<any> = new EventEmitter();
    /**
     * Событие на нажатие кнопки сохранить
     * @type {EventEmitter<any>}
     */
    @Output() onSave: EventEmitter<any> = new EventEmitter();

    /**
     * Конструктор
     */
    constructor() {
    }

    /**
     * Если слайдер открыт и нажата клавиша Escape (27), то закрыть сладйер
     * @param {KeyboardEvent} event
     */
    @HostListener('document:keydown', ['$event'])
    handleKeyboardEvent(event: KeyboardEvent) {
        const key = event.which || event.keyCode;
        // close slider on Escape
        if (key === 27 && this.open === true) {
            this.toggleSlider();
        }
    }

    /**
     * Инициализация
     */
    ngOnInit() {
    }

    /**
     * При изменении статуса открытия блокировать прокрутку фона
     * @param {SimpleChanges} changes
     */
    ngOnChanges(changes: SimpleChanges) {
        if (changes['open'] && !changes['open'].firstChange) {
            this.checkStatus();
        }
    }

    /**
     * Скрыть/показать слайдер
     */
    toggleSlider() {
        this.open = !this.open;
        if (this.open) {
            this.onOpen.emit({open: this.open});
        } else {
            this.onClose.emit({open: this.open});
        }
        this.checkStatus();
        this.openChange.emit(this.open);
    }

    /**
     * Если слайдер открыт, то заблокировать прокрутку страницы позади слайдера
     */
    checkStatus() {
        if (this.open) {
            document.body.style.overflow = 'hidden';
        } else {
            document.body.style.overflow = '';
        }
    }

    /**
     * Нажатие на кнопку Отмена
     */
    cancel() {
        this.onCancel.emit({open: this.open});
    }

    /**
     * Нажатие на кнопку сохранить
     */
    save() {
        this.onSave.emit({open: this.open});
    }

    /**
     * Показывать ли строку с кнопками
     * @returns {boolean}
     */
    withButtons() {
        return this.showSaveBtn || this.showCancelBtn;
    }
}

@NgModule({
    imports: [CommonModule],
    exports: [Slider],
    declarations: [Slider]
})
export class SliderModule {
}

==> glx.ui-1.9.3.tgz: package/components/slider/slider.ts <==
import { Component, EventEmitter, HostListener, Input, NgModule, OnChanges, OnDestroy, OnInit, Output, SimpleChanges } from '@angular/core';
import { CommonModule } from '@angular/common';
import { slideInOutAnimation } from '../kernel/animations/slide.animation';

/**
 * Слайдер
 */
@Component({
    selector: 'glx-slider',
    styleUrls: ['slider.scss'],
    templateUrl: 'slider.html',
    animations: [slideInOutAnimation]
})
export class Slider implements OnInit, OnChanges, OnDestroy {
    /**
     * Признак открытого / закрытого слайдера
     */
    @Input() open: boolean;
    /**
     * Заголовок слайдера
     */
    @Input() header: string;
    /**
     * Показать кнопку отмены
     * @type {boolean}
     */
    @Input() showCancelBtn: boolean = false;
    /**
     * Показать кнопку сохранить
     * @type {boolean}
     */
    @Input() showSaveBtn: boolean = false;

    /**
     * Событие на смену видимости слайдера
     * @type {EventEmitter<boolean>}
     */
    @Output() openChange = new EventEmitter<boolean>();
    /**
     * Событие на открытие слайдера
     * @type {EventEmitter<any>}
     */
    @Output() onOpen: EventEmitter<any> = new EventEmitter();
    /**
     * Собатие на закрытие слайдера
     * @type {EventEmitter<any>}
     */
    @Output() onClose: EventEmitter<any> = new EventEmitter();
    /**
     * Собыытие на нажатие кнопки отмены
     * @type {EventEmitter<any>}
     */
    @Output() onCancel: EventEmitter<any> = new EventEmitter();
    /**
     * Событие на нажатие кнопки сохранить
     * @type {EventEmitter<any>}
     */
    @Output() onSave: EventEmitter<any> = new EventEmitter();

    /**
     * Конструктор
     */
    constructor() {
    }

    /**
     * Если слайдер открыт и нажата клавиша Escape (27), то закрыть сладйер
     * @param {KeyboardEvent} event
     */
    @HostListener('document:keydown', ['$event'])
    handleKeyboardEvent(event: KeyboardEvent) {
        const key = event.which || event.keyCode;
        // close slider on Escape
        if (key === 27 && this.open === true) {
            this.toggleSlider();
        }
    }

    /**
     * Инициализация
     */
    ngOnInit() {
    }

    /**
     * При изменении статуса открытия блокировать прокрутку фона
     * @param {SimpleChanges} changes
     */
    ngOnChanges(changes: SimpleChanges) {
        if (changes['open'] && !changes['open'].firstChange) {
            this.checkStatus();
        }
    }

    ngOnDestroy() {
        document.body.style.overflow = '';
    }

    /**
     * Скрыть/показать слайдер
     */
    toggleSlider() {
        this.open = !this.open;
        if (this.open) {
            this.onOpen.emit({open: this.open});
        } else {
            this.onClose.emit({open: this.open});
        }
        this.checkStatus();
        this.openChange.emit(this.open);
    }

    /**
     * Если слайдер открыт, то заблокировать прокрутку страницы позади слайдера
     */
    checkStatus() {
        if (this.open) {
            document.body.style.overflow = 'hidden';
        } else {
            document.body.style.overflow = '';
        }
    }

    /**
     * Нажатие на кнопку Отмена
     */
    cancel() {
        this.onCancel.emit({open: this.open});
    }

    /**
     * Нажатие на кнопку сохранить
     */
    save() {
        this.onSave.emit({open: this.open});
    }

    /**
     * Показывать ли строку с кнопками
     * @returns {boolean}
     */
    withButtons() {
        return this.showSaveBtn || this.showCancelBtn;
    }
}

@NgModule({
    imports: [CommonModule],
    exports: [Slider],
    declarations: [Slider]
})
export class SliderModule {
}
